pub enum Error {
InitializationFailed(String),
InitializationFailedTimeout(String),
GuestCallNotFound,
WasiDisabled,
WasiInitCtxError(String),
LinkerFuncDef {
func: String,
err: String,
},
BuilderInvalidConfig(String),
Wasmtime(Error),
Generic(Error),
}Expand description
This crate’s Error type
Variants
InitializationFailed(String)
Wasmtime initialization failed
InitializationFailedTimeout(String)
Wasmtime initialization failed
GuestCallNotFound
The guest call function was not exported by the guest.
WasiDisabled
Error originating when wasi feature is disabled, but the user provides wasi related params
WasiInitCtxError(String)
Error originating when wasi context initialization fails
LinkerFuncDef
Error caused when a host function cannot be registered into a wasmtime::Linker
BuilderInvalidConfig(String)
Error caused by an invalid configuration of the crate::WasmtimeEngineProviderBuilder
Wasmtime(Error)
Error raised by wasmtime
Generic(Error)
Generic error