WasmtimeEngineProviderBuilder

Struct WasmtimeEngineProviderBuilder 

pub struct WasmtimeEngineProviderBuilder<'a> { /* private fields */ }
Used to build WasmtimeEngineProvider instances.

Implementations

Source

impl<'a> WasmtimeEngineProviderBuilder<'a>

pub fn new() -> Self

Create a builder instance

pub fn module_bytes(self, module_bytes: &'a [u8]) -> Self

Provide contents of the WebAssembly module

pub fn module(self, module: Module) -> Self

Provide a preloaded wasmtime::Module

Warning: the wasmtime::Engine used to load it must be provided via the WasmtimeEngineProviderBuilder::engine method, otherwise the code will panic at runtime later.

pub fn engine(self, engine: Engine) -> Self

Provide a preinitialized wasmtime::Engine

Warning: when used, engine specific options like cache and enable_epoch_interruptions must be pre-configured by the user. WasmtimeEngineProviderBuilder won’t be able to configure them at build time.

pub fn wasi_params(self, wasi: WasiParams) -> Self

Available on crate feature wasi only.

WASI params

pub fn enable_cache(self, path: Option<&Path>) -> Self

Available on crate feature cache only.

Enable Wasmtime cache feature

Warning: this has no effect when a custom wasmtime::Engine is provided via the WasmtimeEngineProviderBuilder::engine helper. In that case, it’s up to the user to provide a wasmtime::Engine instance with the cache values properly configured.

pub fn enable_epoch_interruptions(self, epoch_deadlines: EpochDeadlines) -> Self

Enable Wasmtime epoch-based interruptions and set the deadlines to be enforced.

Warning: when providing an instance of wasmtime::Engine via the WasmtimeEngineProvider::engine helper, ensure the wasmtime::Engine has been created with the epoch_interruption feature enabled

pub fn build_pre(&self) -> Result<WasmtimeEngineProviderPre, Error>

Create a WasmtimeEngineProviderPre instance. This instance can then be reused as many time as wanted to quickly instantiate a WasmtimeEngineProvider by using the WasmtimeEngineProviderPre::rehydrate method.

pub fn build(&self) -> Result<WasmtimeEngineProvider, Error>

Create a WasmtimeEngineProvider instance

pub fn build_async_pre(&self) -> Result<WasmtimeEngineProviderAsyncPre, Error>

Available on crate feature async only.

Create a WasmtimeEngineProviderAsyncPre instance. This instance can then be reused as many time as wanted to quickly instantiate a WasmtimeEngineProviderAsync by using the WasmtimeEngineProviderAsyncPre::rehydrate method.

Warning: if provided by the user, the wasmtime::Engine must have been created with async support enabled otherwise the code will panic at runtime.

pub fn build_async(&self) -> Result<WasmtimeEngineProviderAsync, Error>

Available on crate feature async only.

Create a WasmtimeEngineProviderAsync instance