pub enum Error {
    InitializationFailed(Box<dyn Error + Send + Sync>),
    InitializationFailedTimeout(String),
    GuestCallNotFound,
    WasiDisabled,
    WasiInitCtxError(String),
    LinkerFuncDef {
        func: String,
        err: String,
    },
    BuilderInvalidConfig(String),
    Generic(Error),
}
This crate’s Error type

Variants

InitializationFailed(Box<dyn Error + Send + Sync>)

Wasmtime initialization failed

InitializationFailedTimeout(String)

Wasmtime initialization failed

GuestCallNotFound

The guest call function was not exported by the guest.

WasiDisabled

Error originating when wasi feature is disabled, but the user provides wasi related params

WasiInitCtxError(String)

Error originating when wasi context initialization fails

LinkerFuncDef

Fields

func: String

wasm function that was being defined

err: String

error reported

Error caused when a host function cannot be registered into a wasmtime::Linker

BuilderInvalidConfig(String)

Error caused by an invalid configuration of the [WasmtimeEngineProviderBuilder]

Generic(Error)

Generic error