pub enum Error {
    InitializationFailed(Box<dyn Error + Send + Sync>),
    InitializationFailedTimeout(String),
    GuestCallNotFound,
    WasiDisabled,
    Generic(Error),
}
This crate’s Error type

Variants

InitializationFailed(Box<dyn Error + Send + Sync>)

Wasmtime initialization failed

InitializationFailedTimeout(String)

Wasmtime initialization failed

GuestCallNotFound

The guest call function was not exported by the guest.

WasiDisabled

Error originating when wasi feature is disabled, but the user provides wasi related params

Generic(Error)

Generic error