pub struct WasmtimeEngineProviderBuilder<'a> { /* private fields */ }Expand description
Used to build WasmtimeEngineProvider instances.
Implementations
Sourceimpl<'a> WasmtimeEngineProviderBuilder<'a>
impl<'a> WasmtimeEngineProviderBuilder<'a>
Sourcepub fn module_bytes(self, module_bytes: &'a [u8]) -> Self
pub fn module_bytes(self, module_bytes: &'a [u8]) -> Self
Provide contents of the WebAssembly module
Sourcepub fn module(self, module: Module) -> Self
pub fn module(self, module: Module) -> Self
Provide a preloaded wasmtime::Module
Warning: the wasmtime::Engine used to load it must be provided via the
WasmtimeEngineProviderBuilder::engine method, otherwise the code
will panic at runtime later.
Sourcepub fn engine(self, engine: Engine) -> Self
pub fn engine(self, engine: Engine) -> Self
Provide a preinitialized wasmtime::Engine
Warning: when used, engine specific options like
cache and
enable_epoch_interruptions
must be pre-configured by the user. WasmtimeEngineProviderBuilder won’t be
able to configure them at build time.
Sourcepub fn wasi_params(self, wasi: WasiParams) -> Self
Available on crate feature wasi only.
pub fn wasi_params(self, wasi: WasiParams) -> Self
wasi only.WASI params
Sourcepub fn enable_cache(self, path: Option<&Path>) -> Self
Available on crate feature cache only.
pub fn enable_cache(self, path: Option<&Path>) -> Self
cache only.Enable Wasmtime cache feature
Warning: this has no effect when a custom wasmtime::Engine is provided via
the WasmtimeEngineProviderBuilder::engine helper. In that case, it’s up to the
user to provide a wasmtime::Engine instance with the cache values properly configured.
Sourcepub fn enable_epoch_interruptions(self, epoch_deadlines: EpochDeadlines) -> Self
pub fn enable_epoch_interruptions(self, epoch_deadlines: EpochDeadlines) -> Self
Enable Wasmtime epoch-based interruptions and set the deadlines to be enforced.
Warning: when providing an instance of wasmtime::Engine via the
WasmtimeEngineProvider::engine helper, ensure the wasmtime::Engine
has been created with the epoch_interruption feature enabled
Sourcepub fn build_pre(&self) -> Result<WasmtimeEngineProviderPre, Error>
pub fn build_pre(&self) -> Result<WasmtimeEngineProviderPre, Error>
Create a WasmtimeEngineProviderPre instance. This instance can then
be reused as many time as wanted to quickly instantiate a WasmtimeEngineProvider
by using the WasmtimeEngineProviderPre::rehydrate method.
Sourcepub fn build(&self) -> Result<WasmtimeEngineProvider, Error>
pub fn build(&self) -> Result<WasmtimeEngineProvider, Error>
Create a WasmtimeEngineProvider instance
Sourcepub fn build_async_pre(&self) -> Result<WasmtimeEngineProviderAsyncPre, Error>
Available on crate feature async only.
pub fn build_async_pre(&self) -> Result<WasmtimeEngineProviderAsyncPre, Error>
async only.Create a WasmtimeEngineProviderAsyncPre instance. This instance can then
be reused as many time as wanted to quickly instantiate a WasmtimeEngineProviderAsync
by using the WasmtimeEngineProviderAsyncPre::rehydrate method.
Warning: if provided by the user, the wasmtime::Engine must have been
created with async support enabled otherwise the code will panic at runtime.
Sourcepub fn build_async(&self) -> Result<WasmtimeEngineProviderAsync, Error>
Available on crate feature async only.
pub fn build_async(&self) -> Result<WasmtimeEngineProviderAsync, Error>
async only.Create a WasmtimeEngineProviderAsync instance